======
Filter
======

Filter commands are used to create real-time filters of output request data.

Create filters
--------------

In Mdb
~~~~~~

.. autoclass:: abaqus.Filter.FilterModel.FilterModel
    :noindex:

    .. autoclasstoc::

In Odb
~~~~~~

.. autoclass:: abaqus.Filter.FilterOdb.FilterOdb
    :noindex:

    .. autoclasstoc::
